.. PyPendentDrop documentation master file, created by
   sphinx-quickstart on Wed Oct 23 22:18:20 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PyPendentDrop documentation
===========================

Open-source Python API with a graphical and command-line interface to measure surface tension coefficients from images of pendent drops.

* Package on `PyPI <https://pypi.org/project/pypendentdrop>`_
* Documentation on `ReadTheDocs <https://pypendentdrop.readthedocs.io>`_
* Source code on `GitHub <https://github.com/Moryavendil/pypendentdrop>`_


PyPendentDrop is heavily inspired from the `Pendent Drop ImageJ plugin <https://github.com/adaerr/pendent-drop>`_.

If you wish to contribute (there are a certain number of things to do in the todo.md file on the GitHub repository), you can contact me by writing at ``pypendentdrop@protonmail.com``.

.. toctree::
   :maxdepth: 1
   :caption: PyPendentDrop documentation:
   
   installation
   howtouse
   method
   API


